@@ -14,7 +14,7 @@ from gmailconnector.send_sms import Messenger
 from urllib3 import disable_warnings
 from urllib3.exceptions import InsecureRequestWarning
 
-from vpn.helper import interactive_ssh, logging_wrapper, time_converter
+from vpn.helper import interactive_ssh, logging_wrapper, time_converter, CURRENT_DIR
 
 disable_warnings(InsecureRequestWarning)  # Disable warnings for self-signed certificates
 
@@ -110,7 +110,7 @@ class VPNServer:
             return False
 
         if response.get('ResponseMetadata').get('HTTPStatusCode') == 200:
-            with open('OpenVPN.pem', 'w') as file:
+            with open(f'{CURRENT_DIR}OpenVPN.pem', 'w') as file:
                 file.write(response.get('KeyMaterial'))
             self.logger.info('Created a key pair named: OpenVPN and stored as OpenVPN.pem')
             return True
@@ -437,8 +437,8 @@ class VPNServer:
 
     def reconfigure_vpn(self):
         """Runs the configuration on an existing VPN server."""
-        if path.isfile('vpn_info.json') and path.isfile('OpenVPN.pem'):
-            with open('vpn_info.json') as file:
+        if path.isfile(f'{CURRENT_DIR}vpn_info.json') and path.isfile(f'{CURRENT_DIR}OpenVPN.pem'):
+            with open(f'{CURRENT_DIR}vpn_info.json') as file:
                 data_exist = load(file)
             self._configure_vpn(data=data_exist)
             if not self._tester(data=data_exist):
@@ -448,8 +448,8 @@ class VPNServer:
 
     def test_vpn(self):
         """Tests the ``GET`` and ``SSH`` connections to an existing VPN server."""
-        if path.isfile('vpn_info.json') and path.isfile('OpenVPN.pem'):
-            with open('vpn_info.json') as file:
+        if path.isfile(f'{CURRENT_DIR}vpn_info.json') and path.isfile(f'{CURRENT_DIR}OpenVPN.pem'):
+            with open(f'{CURRENT_DIR}vpn_info.json') as file:
                 data_exist = load(file)
             self._tester(data=data_exist)
         else:
@@ -464,8 +464,8 @@ class VPNServer:
             - If connects, notifies user with details and adds key-value pair ``Retry: True`` to ``vpn_info.json``
             - If another request is sent to start the vpn, creates a new instance regardless of existing info.
         """
-        if path.isfile('vpn_info.json') and path.isfile('OpenVPN.pem'):
-            with open('vpn_info.json') as file:
+        if path.isfile(f'{CURRENT_DIR}vpn_info.json') and path.isfile(f'{CURRENT_DIR}OpenVPN.pem'):
+            with open(f'{CURRENT_DIR}vpn_info.json') as file:
                 data_exist = load(file)
 
             self.logger.warning(f"Found an existing VPN Server running at {data_exist.get('SERVER')}")
@@ -477,7 +477,7 @@ class VPNServer:
                     self._notify(login_details=f"CURRENTLY SERVING: {data_exist.get('SERVER').lstrip('https://')}\n\n"
                                                f"Username: {data_exist.get('USERNAME')}\n"
                                                f"Password: {data_exist.get('PASSWORD')}")
-                    with open('vpn_info.json', 'w') as file:
+                    with open(f'{CURRENT_DIR}vpn_info.json', 'w') as file:
                         dump(data_exist, file, indent=2)
                     return
             else:
@@ -504,7 +504,7 @@ class VPNServer:
             'security_group_id': security_group_id
         }
 
-        with open('vpn_info.json', 'w') as file:
+        with open(f'{CURRENT_DIR}vpn_info.json', 'w') as file:
             dump(instance_info, file, indent=2)
 
         self.logger.info('Restricting wide open permissions to OpenVPN.pem')
@@ -522,7 +522,7 @@ class VPNServer:
         self.logger.info('VPN server has been configured successfully. Details have been stored in vpn_info.json.')
         url = f"https://{instance_info.get('public_ip')}"
         instance_info.update({'SERVER': f"{url}:{self.port}", 'USERNAME': vpn_username, 'PASSWORD': vpn_password})
-        with open('vpn_info.json', 'w') as file:
+        with open(f'{CURRENT_DIR}vpn_info.json', 'w') as file:
             dump(instance_info, file, indent=2)
 
         self._notify(login_details=f"SERVER: {public_ip}:{self.port}\n\n"
@@ -606,7 +606,7 @@ class VPNServer:
             self.logger.error('Input file: vpn_info.json is missing. CANNOT proceed.')
             return
 
-        with open('vpn_info.json', 'r') as file:
+        with open(f'{CURRENT_DIR}vpn_info.json', 'r') as file:
             data = load(file)
 
         if self._delete_key_pair() and self._terminate_ec2_instance(instance_id=data.get('instance_id')):
